==> MiningMart-1.0-src.zip: MiningMart-1.0/src/edu/udo/cs/miningmart/gui/util/M4ObjectComparator.java <==
/*
 * MiningMart Version 1.0
 * 
 * Copyright (C) 2006 Martin Scholz, Timm Euler, 
 *                    Daniel Hakenjos, Katharina Morik
 *
 * Contact: miningmart@ls8.cs.uni-dortmund.de
 *
 * A list of contributing developers (other than the copyright 
 * holders) can be found at
 * http://mmart.cs.uni-dortmund.de/downloads/download.html
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program, see the file MM_HOME/LICENSE; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 */
package edu.udo.cs.miningmart.gui.util;

import java.util.Comparator;

import edu.udo.cs.miningmart.m4.M4Object;

/**
 * @author Daniel Hakenjos
 * @version $Id: M4ObjectComparator.java,v 1.3 2006/04/11 14:10:18 euler Exp $
 */
public class M4ObjectComparator implements Comparator{

	/* (non-Javadoc)
	 * @see java.util.Comparator#compare(java.lang.Object, java.lang.Object)
	 */
	public int compare(Object object1, Object object2) {
		M4Object m4object1=null,m4object2=null;
		if ((object1 instanceof M4Object)&&(object2 instanceof M4Object)) {
			m4object1=(M4Object) object1;			
			m4object2=(M4Object) object2;			
			return m4object1.getName().compareTo(m4object2.getName());
		}
		return 0;
	}

}
/*
 * Historie
 * --------
 *
 * $Log: M4ObjectComparator.java,v $
 * Revision 1.3  2006/04/11 14:10:18  euler
 * Updated license text.
 *
 * Revision 1.2  2006/04/06 16:31:17  euler
 * Prepended license remark.
 *
 * Revision 1.1  2006/01/03 09:54:34  hakenjos
 * Initial version!
 *
 */

==> MiningMart-1.1-src.zip: MiningMart-1.1/src/edu/udo/cs/miningmart/gui/util/M4ObjectComparator.java <==
/*
 * MiningMart Version 1.1
 * 
 * Copyright (C) 2006 Martin Scholz, Timm Euler, 
 *                    Daniel Hakenjos, Katharina Morik
 *
 * Contact: miningmart@ls8.cs.uni-dortmund.de
 *
 * A list of contributing developers (other than the copyright 
 * holders) can be found at
 * http://mmart.cs.uni-dortmund.de/downloads/download.html
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program, see the file MM_HOME/LICENSE; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 */
package edu.udo.cs.miningmart.gui.util;

import java.util.Comparator;

import edu.udo.cs.miningmart.m4.BaseAttribute;
import edu.udo.cs.miningmart.m4.Feature;
import edu.udo.cs.miningmart.m4.M4Object;

/**
 * @author Daniel Hakenjos
 * @version $Id: M4ObjectComparator.java,v 1.4 2006/09/27 15:00:04 euler Exp $
 */
public class M4ObjectComparator implements Comparator{

	/* (non-Javadoc)
	 * @see java.util.Comparator#compare(java.lang.Object, java.lang.Object)
	 */
	public int compare(Object object1, Object object2) {
		M4Object m4object1=null,m4object2=null;
		if ((object1 instanceof M4Object)&&(object2 instanceof M4Object)) {
			m4object1=(M4Object) object1;			
			m4object2=(M4Object) object2;
			
			// Special case: in a collection of features
			// we want the DB-Features listed first, then
			// the MINING-Features
			if (m4object1 instanceof BaseAttribute && 
				m4object2 instanceof BaseAttribute) {
				BaseAttribute ba1 = (BaseAttribute) m4object1;
				BaseAttribute ba2 = (BaseAttribute) m4object2;
				if (ba1.getType().equalsIgnoreCase(BaseAttribute.TYPE_DB) &&
					ba2.getType().equalsIgnoreCase(BaseAttribute.TYPE_MINING)) {
					return -1;
				}
				if (ba1.getType().equalsIgnoreCase(BaseAttribute.TYPE_MINING) &&
					ba2.getType().equalsIgnoreCase(BaseAttribute.TYPE_DB)) {
						return 1;
				}
			}
			
			return m4object1.getName().compareTo(m4object2.getName());
		}
		return 0;
	}

}
/*
 * Historie
 * --------
 *
 * $Log: M4ObjectComparator.java,v $
 * Revision 1.4  2006/09/27 15:00:04  euler
 * New version 1.1
 *
 * Revision 1.3  2006/04/11 14:10:18  euler
 * Updated license text.
 *
 * Revision 1.2  2006/04/06 16:31:17  euler
 * Prepended license remark.
 *
 * Revision 1.1  2006/01/03 09:54:34  hakenjos
 * Initial version!
 *
 */
